@@ -131,7 +131,7 @@ class AppInfo(object):
         contains app information previously located in GUI.py
     """
     NAME = 'Nagstamon'
-    VERSION = '3.14.0'
+    VERSION = '3.16.0'
     WEBSITE = 'https://nagstamon.de'
     COPYRIGHT = '©2008-2024 Henri Wahl et al.'
     COMMENTS = 'Nagios status monitor for your desktop'
@@ -1076,7 +1076,6 @@ except Exception as err:
         # if resources dir is not available in CWD, try the
         # libs dir (site-packages) for the current Python
         from distutils.sysconfig import get_python_lib
-
         paths_to_check.append(os.path.normcase(os.path.join(get_python_lib(), "Nagstamon", "resources")))
     except Exception:
         pass
@@ -1084,7 +1083,6 @@ except Exception as err:
     # if we're still out of luck, maybe this was a user scheme install
     try:
         import site
-
         site.getusersitepackages()  # make sure USER_SITE is set
         paths_to_check.append(os.path.normcase(os.path.join(site.USER_SITE, "Nagstamon", "resources")))
     except Exception:
@@ -1096,6 +1094,12 @@ except Exception as err:
     for path in paths_to_check:
         if os.path.exists(path):
             RESOURCES = path
+            print('resources 3: ' + RESOURCES, paths_to_check)
             break
     else:
         RESOURCES = str(Path(__file__).parent.absolute().joinpath('resources'))
+
+# try to fix missing resources path for Windows
+if OS == OS_WINDOWS:
+    if r'\_internal\Nagstamon\resources' in RESOURCES:
+        RESOURCES = RESOURCES.replace(r'\_internal\Nagstamon\resources', r'\_internal\resources')
